OC.L10N.register(
    "core",
    {
    "Please select a file." : "Kies asb. ’n lêer.",
    "File is too big" : "Lêer is te groot",
    "The selected file is not an image." : "Die gekose lêer is nie ’n beeld nie.",
    "The selected file cannot be read." : "Die gekose lêer kan nie gelees word nie.",
    "Invalid file provided" : "Ongeldige lêer verskaf",
    "No image or file provided" : "Geen beeld of lêer verskaf nie",
    "Unknown filetype" : "Onbekende lêertipe",
    "Invalid image" : "Ongeldige beeld",
    "An error occurred. Please contact your admin." : "'n Fout het voorgekom. Kontak asseblief u administrateur.",
    "No temporary profile picture available, try again" : "Geen tydelike profielfoto beskikbaar nie, probeer weer",
    "No crop data provided" : "Geen snoeidata verskaf nie",
    "No valid crop data provided" : "Geen geldige snoeidata verskaf nie",
    "Crop is not square" : "Snoei is nie vierkantig nie",
    "State token does not match" : "Toestandteken pas nie",
    "Password reset is disabled" : "Wagwoordherstel is gedeaktiveer",
    "Couldn't reset password because the token is invalid" : "Kon nie wagwoord herstel nie aangesien die teken ongeldig is",
    "Couldn't reset password because the token is expired" : "Kon nie wagwoord herstel nie aangesien die teken verval het",
    "%s password reset" : "%s wagwoord herstel",
    "Password reset" : "Wagwoord herstel",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klik op die volgende knoppie om jou wagwoord te herstel. As jy nie 'n wagwoordherstel aangevra het nie, ignoreer dié e-pos.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klik op die volgende skakel om jou wagwoord te herstel. As jy nie 'n wagwoordherstel aangevra het nie, ignoreer dié e-pos.",
    "Reset your password" : "Herstel jou wagwoord",
    "Preparing update" : "Berei bywerking voor",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Ondersoek tans tabel %s",
    "Turned on maintenance mode" : "Onderhoudsmodus is aangeskakel",
    "Turned off maintenance mode" : "Onderhoudsmodus is afgeskakel",
    "Maintenance mode is kept active" : "Onderhoudsmodus word aktief gehou",
    "Updating database schema" : "Werk tans databasis skema by",
    "Updated database" : "Databasis is bygewerk",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Ondersoek tans of die databasis skema bygewerk kan word (afhangende van die databasis grootte kan dit lank neem)",
    "Checked database schema update" : "Databasis skema bywerking nagegaan",
    "Checking updates of apps" : "Kontroleer tans bywerking vir toeps",
    "Checking for update of app \"%s\" in appstore" : "Kontroleer tans bywerking vir toep \"%s\" in die toepwinkel",
    "Update app \"%s\" from appstore" : "Werk toep \"%s\" van die toepwinkel by",
    "Starting code integrity check" : "Kode integriteit word tans nagegaan",
    "Finished code integrity check" : "Kode integriteit is suksesvol nagegaan",
    "%s (incompatible)" : "%s (onversoenbaar)",
    "Following apps have been disabled: %s" : "Die volgende toeps is gedeaktiveer: %s",
    "Already up to date" : "Reeds op datum",
    "Very weak password" : "Baie swak wagwoord",
    "Weak password" : "Swak wagwoord",
    "So-so password" : "Gemiddelde wagwoord",
    "Good password" : "Goeie wagwoord",
    "Strong password" : "Sterk wagwoord",
    "Error occurred while checking server setup" : "'n Fout het voorgekom tydens die nagaan van die bediener se konfigurasie",
    "Non-existing tag #{tag}" : "Merker #{tag} bestaan nie",
    "restricted" : "beperk",
    "invisible" : "onsigbaar",
    "({scope})" : "({scope})",
    "Delete" : "Skrap",
    "Rename" : "Hernoem",
    "Collaborative tags" : "Samewerkende merkers",
    "No tags found" : "Geen merkers gevind nie",
    "unknown text" : "onbekende teks",
    "Hello world!" : "Hallo wêreld!",
    "sunny" : "sonnig",
    "Hello {name}, the weather is {weather}" : "Hallo {name}, die weer is {weather}",
    "Hello {name}" : "Hallo {name}",
    "new" : "nuwe",
    "_download %n file_::_download %n files_" : ["%n leër afgelaai","%n leërs afgelaai"],
    "Update to {version}" : "Werk by na {version}",
    "An error occurred." : "'n Fout het voorgekom.",
    "Please reload the page." : "Herlaai asseblief die bladsy.",
    "Continue to Nextcloud" : "Gaan voort na Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["Die bywerking was suksesvol. U gaan oor %n sekonde na Nextcloud herlei word.","Die bywerking was suksesvol. U gaan oor %n sekondes na Nextcloud herlei word."],
    "Searching other places" : "Soek tans in ander plekke",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} soek resultaat in 'n ander gids","{count} soek resultate in ander gidse"],
    "Please contact your administrator." : "Kontak asseblief jou administrateur.",
    "An internal error occurred." : "'n Interne fout het voorgekom.",
    "Please try again or contact your administrator." : "Probeer asseblief weer of kontak jou administrateur.",
    "Username or email" : "Gebruikersnaam of e-pos",
    "Password" : "Wagwoord",
    "Log in" : "Meld aan",
    "Logging in …" : "Meld tans aan …",
    "Wrong username or password." : "Verkeerde gebruikersnaam of wagwoord.",
    "Reset password" : "Herstel wagwoord",
    "Couldn't send reset email. Please contact your administrator." : "Kon nie die herstel-e-pos stuur nie. Kontak asseblief jou administrateur.",
    "Password can not be changed. Please contact your administrator." : "Wagwoord kan nie verander word nie. Kontak asseblief u administrateur.",
    "Back to login" : "Terug na aanmelding",
    "New password" : "Nuwe wagwoord",
    "I know what I'm doing" : "Ek weet wat ek doen",
    "Cancel" : "Kanselleer",
    "Forgot password?" : "Wagwoord vergeet?",
    "Settings" : "Instellings",
    "Could not load your contacts" : "Kon nie u kontakte laai nie",
    "Search contacts …" : "Soek kontakte …",
    "No contacts found" : "Geen kontakte gevind nie",
    "Show all contacts …" : "Vertoon alle kontakte …",
    "Loading your contacts …" : "Laai tans u kontakte …",
    "Looking for {term} …" : "Soek tans vir {term} …",
    "No" : "Nee",
    "Yes" : "Ja",
    "No files in here" : "Geen lêers hier nie",
    "New folder" : "Nuwe vouer",
    "Name" : "Naam",
    "Size" : "Grootte",
    "Modified" : "Gewysig",
    "{newName} already exists" : "{newName} bestaan reeds",
    "Choose" : "Kies",
    "Copy" : "Kopieer",
    "Move" : "Skuif",
    "OK" : "OK",
    "read-only" : "lees-alleen",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} lêerkonflik","{count} lêerkonflikte"],
    "One file conflict" : "Een lêerkonflik",
    "New Files" : "Nuwe lêers",
    "Already existing files" : "Reeds bestaande lêers",
    "Which files do you want to keep?" : "Watter lêers wil jy hou?",
    "Continue" : "Gaan voort",
    "(all selected)" : "(almal gekies)",
    "({count} selected)" : "({count} gekies)",
    "Pending" : "Hangend",
    "Copy to {folder}" : "Kopieer na {folder}",
    "Move to {folder}" : "Skuif na {folder}",
    "Saving..." : "Stoor tans…",
    "Authentication required" : "Verifikasie word vereis",
    "This action requires you to confirm your password" : "Die aksie vereis dat jy jou wagwoord bevestig",
    "Confirm" : "Bevestig",
    "Failed to authenticate, try again" : "Kon nie verifieer nie, probeer weer",
    "seconds ago" : "sekondes gelede",
    "Connection to server lost" : "Verbinding met bediener verloor",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleem om bladsy te laai, herlaai in %n sekonde","Probleem om bladsy te laai, herlaai oor %n sekondes"],
    "No action available" : "Geen beskikbare aksies nie",
    "Personal" : "Persoonlik",
    "Users" : "Gebruikers",
    "Apps" : "Toeps",
    "Admin" : "Admin",
    "Help" : "Hulp",
    "Access forbidden" : "Toegang verbode",
    "File not found" : "Lêer nie gevind nie",
    "Back to %s" : "Terug na %s",
    "Error" : "Fout",
    "Internal Server Error" : "Interne bedienerfout",
    "The server was unable to complete your request." : "Die bediener was nie in staat om u versoek te voltooi nie.",
    "More details can be found in the server log." : "Meer besonderhede kan in die bediener joernaal gevind word.",
    "Technical details" : "Tegniese besonderhede",
    "Remote Address: %s" : "Afgeleë adres: %s",
    "Request ID: %s" : "Versoek-ID: %s",
    "Type: %s" : "Tipe: %s",
    "Code: %s" : "Kode: %s",
    "Message: %s" : "Boodskap: %s",
    "File: %s" : "Lêer: %s",
    "Line: %s" : "Lyn: %s",
    "Trace" : "Spoor",
    "Security warning" : "Sekuriteitswaarskuwing",
    "Username" : "Gebruikernaam",
    "Storage & database" : "Berging & databasis",
    "Data folder" : "Datagids",
    "Only %s is available." : "Slegs %s is beskikbaar.",
    "Database user" : "Databasisgebruiker",
    "Database password" : "Databasis wagwoord",
    "Database name" : "Databasisnaam",
    "Database tablespace" : "Databasistabelruimte",
    "Database host" : "Databasis gasheer",
    "Finish setup" : "Voltooi opstelling",
    "Finishing …" : "Maak klaar …",
    "Need help?" : "Hulp nodig?",
    "See the documentation" : "Lees die dokumentasie",
    "More apps" : "Meer toeps",
    "More" : "Meer",
    "Search" : "Soek",
    "Reset search" : "Herstel soek",
    "Contacts" : "Kontakte",
    "Contacts menu" : "Kontakkieslys",
    "Settings menu" : "Instellingskieslys",
    "Confirm your password" : "Bevestig jou wagwoord",
    "App token" : "Toep-tekseenheid",
    "Grant access" : "Verleen toegang",
    "Account access" : "Rekening toegang",
    "The password is wrong. Try again." : "Die wagwoord is verkeerd. Probeer weer.",
    "Two-factor authentication" : "Twee-faktor-verifikasie",
    "Use backup code" : "Gebruik rugsteunkode",
    "Error while validating your second factor" : "Fout terwyl u tweede faktor gevalideer word",
    "App update required" : "Toepbywerking benodig",
    "These apps will be updated:" : "Die volgende toeps sal bygewerk word:",
    "These incompatible apps will be disabled:" : "Die volgende onversoenbare toeps sal gedeaktiveer word:",
    "The theme %s has been disabled." : "Die tema %s is gedeaktiveer.",
    "Start update" : "Begin bywerking",
    "Detailed logs" : "Gedetailleerde joernale",
    "Update needed" : "Bywerking benodig",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Kon nie die herstel-e-pos stuur nie aangesien daar geen e-posadres met die gebruikersnaam geassosieer is nie. Kontak asseblief jou administrateur.",
    "Couldn't send reset email. Please make sure your username is correct." : "Kon nie die herstel e-pos stuur nie. Kontroleer jou gebruikersnaam.",
    "Dismiss" : "Ontslaan",
    "Sending email …" : "Stuur tans e-pos …",
    "Shared" : "Gedeel",
    "Shared with" : "Gedeel met",
    "Shared by" : "Gedeel deur",
    "Choose a password for the public link" : "Kies 'n wagwoord vir die publieke skakel",
    "Choose a password for the public link or press the \"Enter\" key" : "Kies 'n wagwoord vir die publieke skakel, of druk die \"Enter\" sleutel",
    "Copied!" : "Gekopieer!",
    "Copy link" : "Kopieer skakel",
    "Not supported!" : "Word nie ondersteun nie!",
    "Press ⌘-C to copy." : "Druk ⌘-C om te kopieer.",
    "Press Ctrl-C to copy." : "Druk Ctrl-C om te kopieer.",
    "Resharing is not allowed" : "Herdeling word nie toegelaat nie",
    "Link" : "Skakel",
    "Password protect" : "Beskerm met 'n wagwoord",
    "Allow editing" : "Laat redigering toe",
    "Email link to person" : "Stuur die skakel per e-pos na die persoon",
    "Send" : "Stuur",
    "Allow upload and editing" : "Laat oplaai en redigering toe",
    "Read only" : "Leesalleen",
    "File drop (upload only)" : "Lêer val (slegs oplaai)",
    "Set expiration date" : "Stel vervaldatum",
    "Expiration" : "Verval",
    "Expiration date" : "Vervaldatum",
    "Unshare" : "Ontdeel",
    "Share to {name}" : "Deel met {name}",
    "Share link" : "Deel skakel",
    "Could not unshare" : "Kon nie ontdeel nie",
    "Shared with you and the group {group} by {owner}" : "Gedeel met u en die groep {group} deur {owner}",
    "Shared with you by {owner}" : "Gedeel met u deur {owner}",
    "Choose a password for the mail share" : "Kies 'n wagwoord vir die e-pos lêer deel ",
    "group" : "groep",
    "remote" : "afgeleë",
    "email" : "e-pos",
    "shared by {sharer}" : "gedeel deur {sharer}",
    "Can reshare" : "Kan herdeel",
    "Can edit" : "Kan redigeer",
    "Can create" : "Kan skep",
    "Can change" : "Kan verander",
    "Can delete" : "Kan skrap",
    "Access control" : "Toegangsbeheer",
    "Error while sharing" : "Fout terwyl deel",
    "Share details could not be loaded for this item." : "Deel besonderhede kon nie vir die item gelaai word nie.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Ten minste {count} karakter word benodig vir outomatiese aanvulling","Ten minste {count} karakters word benodig vir outomatiese aanvulling"],
    "No users or groups found for {search}" : "Geen gebruikers of groepe gevind vir {search}",
    "No users found for {search}" : "Geen gebruiker gevind vir {search}",
    "An error occurred (\"{message}\"). Please try again" : "'n Fout het voorgekom (\"{message}\"). Probeer asseblief weer",
    "An error occurred. Please try again" : "'n Fout het voorgekom. Probeer asseblief weer",
    "Home" : "Tuis",
    "Work" : "Werk",
    "Other" : "Ander",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "Deel",
    "Name or email address..." : "Naam of e-posadres...",
    "Name or federated cloud ID..." : "Naam of gefedereerde wolk-ID...",
    "Name, federated cloud ID or email address..." : "Naam, gefedereerde wolk-ID of e-posadres...",
    "Name..." : "Naam...",
    "Error removing share" : "Fout terwyl deel verwyder word",
    "SQLite will be used as database." : "SQLite sal as databasis gebruik word.",
    "Wrong password." : "Verkeerde wagwoord.",
    "New Password" : "Nuwe wagwoord",
    "Cancel log in" : "Kanselleer aanmelding"
},
"nplurals=2; plural=(n != 1);");
